'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _rollupPluginBabelHelpers = require('./_virtual/_rollupPluginBabelHelpers.cjs');
var umi = require('@metaplex-foundation/umi');

class ProgramNotRecognizedError extends umi.SdkError {
  constructor(identifier, cluster) {
    const isName = typeof identifier === 'string';
    const toString = isName ? identifier : umi.base58PublicKey(identifier);
    const clusterString = cluster === '*' ? 'any' : `the [${cluster}]`;
    const message = `The provided program ${isName ? 'name' : 'address'} [${toString}] ` + `is not recognized in ${clusterString} cluster. ` + 'Did you forget to register this program? ' + 'If so, you may use "context.programs.add(myProgram)" to fix this.';
    super(message);
    _rollupPluginBabelHelpers.defineProperty(this, "name", 'ProgramNotRecognizedError');
    this.identifier = identifier;
    this.cluster = cluster;
  }
}

/** @group Errors */
class ProgramErrorNotRecognizedError extends umi.ProgramError {
  constructor(program, cause) {
    const ofCode = cause.code ? ` of code [${cause.code}]` : '';
    const message = `The program [${program.name}] ` + `at address [${umi.base58PublicKey(program.publicKey)}] ` + `raised an error${ofCode} ` + `that is not recognized by the programs registered on the SDK. ` + `Please check the underlying program error below for more details.`;
    super(message, program, cause);
    _rollupPluginBabelHelpers.defineProperty(this, "name", 'ProgramErrorNotRecognizedError');
  }
}

exports.ProgramErrorNotRecognizedError = ProgramErrorNotRecognizedError;
exports.ProgramNotRecognizedError = ProgramNotRecognizedError;
//# sourceMappingURL=errors.cjs.map
